<?php

namespace App\Http\Controllers;

use App\Models\MenuSection;
use App\Models\ServiceList;
use App\Models\SubServiceList;
use App\Models\SubSubServiceList;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Str;

class FolderController extends Controller
{
    public function reloadFolder()
    {
        $basePath = $_SERVER['DOCUMENT_ROOT'] . '/';
        $serviceFolders = array_map('basename', File::directories($basePath));

        // Excluded folders
        $excludeFolder = [
            'admin',
            'builder-templates',
            'css',
            'images',
            'includes',
        ];
        $serviceFolders = array_diff($serviceFolders, $excludeFolder);
        $serviceFolders = array_values($serviceFolders);

        foreach ($serviceFolders as $serviceFolder) {
            $serviceSlug = Str::slug($serviceFolder);

            // Find or create the ServiceList
            $service = ServiceList::firstOrCreate(
                ['slug' => $serviceSlug],
                ['name' => $serviceFolder]
            );

            $subPath = $basePath . '/' . $serviceFolder;
            $subFolders = array_map('basename', File::directories($subPath));

            foreach ($subFolders as $subFolder) {
                $subSlug = Str::slug($subFolder);

                // Find or create SubServiceList using only slug
                $subService = SubServiceList::firstOrCreate(
                    ['slug' => $subSlug],
                    [
                        'services_list_id' => $service->id,
                        'name' => $subFolder,
                    ]
                );

                $subSubPath = $subPath . '/' . $subFolder;
                $subSubFolders = array_map('basename', File::directories($subSubPath));

                foreach ($subSubFolders as $subSubFolder) {
                    $subSubSlug = Str::slug($subSubFolder);

                    // Find or create SubSubServiceList using only slug
                    SubSubServiceList::firstOrCreate(
                        ['slug' => $subSubSlug],
                        [
                            'sub_services_list_id' => $subService->id,
                            'services_list_id' => $service->id,
                            'name' => $subSubFolder,
                        ]
                    );
                }
            }
        }

        return redirect()->route('dashboard');
    }

    public function getMaxSection(Request $request)
    {
        $type = $request->type;
        $id = $request->caseStudyId;

        $menuSections = MenuSection::where('edit_page_id', $id)->where('type', $type)->first();
        $additional_data = json_decode($menuSections->additional_data);

        $numbers = [];
        foreach ($additional_data as $item) {
            if (preg_match('/\d+/', $item, $matches)) {
                $numbers[] = (int)$matches[0];
            }
        }

        $maxNumber = !empty($numbers) ? max($numbers) : 0; // Default to 0 if no numbers are found
        $newSectionName = 'section' . ($maxNumber + 1);
        $fileName = 'section' . ($maxNumber + 1) . '.blade.php'; // Generate file name

        $filePath = resource_path('views/components/' . $type . '/' . $fileName); // Full path to the file
        $filePathPublish = resource_path('views/components/' . $type . '-publish/' . $fileName);

        // Check if the directory exists; if not, create it
        if (!file_exists(dirname($filePath))) {
            mkdir(dirname($filePath), 0755, true);
        }

        // File content
        $fileContent = '<div class="form-group row mb-4 color-five section-drag code-snippet-custom" id="' . ($newSectionName) . '">
                        <div class="col-12 mx-auto">
                            <label class="">Custom section' . ($maxNumber + 1) . '</label>
                            <textarea class="summernote-simple" name="code_snippet_custom[]">{{ $value ?? "" }}</textarea>
                            <input type="hidden" name="code_snippet_custom_ids[]" value="' . ($newSectionName) . '">
                        </div>
                        <div class="controls col-md-12">
                            <button class="move-up" type="button" data-toggle="tooltip" title="Move Section Up"><i class="fas fa-arrow-up"></i></button>
                            <button class="move-down" type="button" data-toggle="tooltip" title="Move Section Down"><i class="fas fa-arrow-down"></i></button>
                        </div>
                    </div>';

        file_put_contents($filePath, $fileContent);

        $fileContentPublish = '<section class="articles-advantage">
                <div class="container">
                    <?php echo $value ?? "" ?>
                </div>
            </section>';
        file_put_contents($filePathPublish, $fileContentPublish);

        $fileContentCopy = '<div class="form-group row mb-4 color-five section-drag code-snippet-custom" id="' . ($newSectionName) . '">
                        <div class="col-12 mx-auto">
                            <label class="">Custom section' . ($maxNumber + 1) . '</label>
                            <textarea class="summernote-simple" name="code_snippet_custom[]"></textarea>
                            <input type="hidden" name="code_snippet_custom_ids[]" value="' . ($newSectionName) . '">
                        </div>
                        <div class="controls col-md-12">
                            <button class="move-up" type="button" data-toggle="tooltip" title="Move Section Up"><i class="fas fa-arrow-up"></i></button>
                            <button class="move-down" type="button" data-toggle="tooltip" title="Move Section Down"><i class="fas fa-arrow-down"></i></button>
                        </div>
                    </div>';

        // Add the new section name to the array
        $additional_data[] = $newSectionName;

        // Save the updated additional data back to the model
        $menuSections->additional_data = json_encode($additional_data);
        $menuSections->save();

        // Return the section content
        return response()->json([
            'success' => true,
            'section' => $fileContentCopy, // Pass the file content as JSON
        ]);
    }
}
