<?php

namespace App\Http\Controllers;

use App\Models\MenuSection;
use Illuminate\Http\Request;

class MenuController extends Controller
{

    public function storeOrUpdateMenu(Request $request)
    {
        try {
            // Validate the incoming request data
            $request->validate([
                'edit_page_id' => 'required|exists:services,id',  // Ensure that the edit_page_id exists in the pages table
                'menu_data' => 'required|array',
                'type' => 'required|string',
            ]);

            $menuData = [];

            foreach ($request->menu_data as $menu) {
                $menuData[$menu['name']] = $menu['order'];  // Use name as key and order as value
            }

            // Prepare the data for storing or updating
            $menuSectionData = [
                'edit_page_id' => $request->edit_page_id,
                'type' => $request->type,
                'additional_data' => json_encode($menuData),  // Store the menu as a JSON object
            ];

            // Store or update the menu section
            MenuSection::updateOrCreate(
                ['edit_page_id' => $request->edit_page_id, 'type' => $request->type],
                $menuSectionData
            );

            return response()->json(['message' => 'Menu updated successfully.']);
        } catch (\Exception $e) {
            // If an error occurs, return a JSON error response
            return response()->json(['error' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
}